@@ -26,6 +26,7 @@
 #include <QDoubleSpinBox>
 #include <QToolButton>
 #include <QTimer>
+#include <QElapsedTimer>
 #include <QGestureEvent>
 #include <QPinchGesture>
 
@@ -103,7 +104,7 @@ public:
     QFont m_font;
     QString m_text;
     Qt::Alignment m_alignment;
-    QTime time;
+    QElapsedTimer time;
 protected slots:
     void doRedraw();
 
@@ -234,7 +235,7 @@ class gToolTip : public QObject
     /*! \fn virtual void display(QString text, int x, int y, int timeout=2000);
         \brief Set the tooltips display message, position, and timeout value
         */
-    virtual void display(QString text, int x, int y, ToolTipAlignment align = TT_AlignCenter, int timeout = 0);
+    virtual void display(QString text, int x, int y, ToolTipAlignment align = TT_AlignCenter, int timeout = 0,bool alwaysShow=false);
 
     //! \brief Draw the tooltip
     virtual void paint(QPainter &paint); //actually paints it.
@@ -396,11 +397,13 @@ class gGraphView
     //! \brief Supplies time range to all graph objects in linked group, refreshing if requested
     void SetXBounds(qint64 minx, qint64 maxx, short group = 0, bool refresh = true);
 
+    QString settingsFilename (QString title,QString folderName="" ,QString ext=".shg");
+
     //! \brief Saves the current graph order, heights, min & Max Y values to disk
-    void SaveSettings(QString title);
+    void SaveSettings(QString title,QString folderName="");
 
     //! \brief Loads the current graph order, heights, min & max Y values from disk
-    bool LoadSettings(QString title);
+    bool LoadSettings(QString title,QString folderName="");
 
     //! \brief Saves the current (initial) graph order, heights, min & Max Y values for future recovery
     void SaveDefaultSettings();
@@ -715,7 +718,7 @@ class gGraphView
 
     QPixmapCache pixmapcache;
 
-    QTime horizScrollTime, vertScrollTime;
+    QElapsedTimer horizScrollTime, vertScrollTime;
     QMenu * context_menu;
     QAction * pin_action;
     QAction * popout_action;
