@@ -185,6 +185,21 @@ QString getGraphicsEngine()
     return gfxEngine;
 }
 
+QString getCompilerVersion()
+{
+    #ifdef __clang_version__
+        return QString("clang++:%1").arg(__clang_version__);
+    #elif defined(__MINGW64__)
+        return QString("MINGW64:%1").arg(__VERSION__);
+    #elif defined(__MINGW32__)
+        return QString("MINGW32:%1").arg(__VERSION__);
+    #elif defined (__GNUG__) or defined (__GNUC__)
+        return QString("GNU C++:%1").arg(__VERSION__);
+    #else
+        return QString();
+    #endif
+}
+
 QStringList buildInfo;
 
 QStringList makeBuildInfo (QString forcedEngine){
@@ -194,6 +209,10 @@ QStringList makeBuildInfo (QString forcedEngine){
     buildInfo << (QObject::tr("Operating system:") + " " + QSysInfo::prettyProductName());
     buildInfo << (QObject::tr("Graphics Engine:") + " " + getOpenGLVersionString());
     buildInfo << (QObject::tr("Graphics Engine type:") + " " + getGraphicsEngine());
+    QString compiler = getCompilerVersion();
+    if (compiler.length() >0 )
+        buildInfo << (QObject::tr("Compiler:") + " " + compiler);
+
     if (forcedEngine != "")
         buildInfo << forcedEngine;
 
@@ -283,7 +302,7 @@ QString weightString(float kg, UnitSystem us)
     if (us == US_Metric) {
         return QString("%1kg").arg(kg, 0, 'f', 2);
     } else if (us == US_English) {
-        int oz = (kg * 1000.0) / (float)ounce_convert;
+        int oz = (kg * 1000.0) * (float)gram_ounce_convert;
         int lb = oz / 16.0;
         oz = oz % 16;
         return QString("%1lb %2oz").arg(lb, 0, 10).arg(oz);
@@ -464,6 +483,7 @@ QString STR_UNIT_CMH2O;
 QString STR_UNIT_Hours;
 QString STR_UNIT_Minutes;
 QString STR_UNIT_Seconds;
+QString STR_UNIT_milliSeconds;
 QString STR_UNIT_h;
 QString STR_UNIT_m;
 QString STR_UNIT_s;
@@ -526,6 +546,9 @@ QString STR_TR_CPAP;    // Constant Positive Airway Pressure
 QString STR_TR_BIPAP;   // Bi-Level Positive Airway Pressure
 QString STR_TR_BiLevel; // Another name for BiPAP
 QString STR_TR_EPAP;    // Expiratory Positive Airway Pressure
+QString STR_TR_EEPAP;    // End Expiratory Positive Airway Pressure
+QString STR_TR_EEPAPLo;  // End-Expiratory Positive Airway Pressure, Low
+QString STR_TR_EEPAPHi;  // End-Expiratory Positive Airway Pressure, High
 QString STR_TR_EPAPLo;  // Expiratory Positive Airway Pressure, Low
 QString STR_TR_EPAPHi;  // Expiratory Positive Airway Pressure, High
 QString STR_TR_IPAP;    // Inspiratory Positive Airway Pressure
@@ -673,6 +696,7 @@ void initializeStrings()
     STR_UNIT_Hours = QObject::tr("Hours");
     STR_UNIT_Minutes = QObject::tr("Minutes");
     STR_UNIT_Seconds = QObject::tr("Seconds");
+    STR_UNIT_milliSeconds = QObject::tr("milliSeconds");
     STR_UNIT_h = QObject::tr("h"); // hours shortform
     STR_UNIT_m = QObject::tr("m"); // minutes shortform
     STR_UNIT_s = QObject::tr("s"); // seconds shortform
@@ -713,7 +737,7 @@ void initializeStrings()
 
     STR_TR_BMI = QObject::tr("BMI");              // Short form of Body Mass Index
     STR_TR_Weight = QObject::tr("Weight");
-    STR_TR_Zombie = QObject::tr("Zombie");
+    STR_TR_Zombie = QObject::tr("Feeling");
     STR_TR_PulseRate = QObject::tr("Pulse Rate"); // Pulse / Heart rate
     STR_TR_SpO2 = QString("SpO2");
     STR_TR_Plethy = QObject::tr("Plethy");        // Plethysomogram
@@ -735,6 +759,9 @@ void initializeStrings()
     STR_TR_BIPAP = QObject::tr("BiPAP");  // Bi-Level Positive Airway Pressure
     STR_TR_BiLevel = QObject::tr("Bi-Level"); // Another name for BiPAP
     STR_TR_EPAP = QObject::tr("EPAP");    // Expiratory Positive Airway Pressure
+    STR_TR_EEPAP = QObject::tr("EEPAP");    // End-Expiratory Positive Airway Pressure
+    STR_TR_EEPAPLo = QObject::tr("Min EEPAP");    // Lower End-Expiratory Positive Airway Pressure
+    STR_TR_EEPAPHi = QObject::tr("Max EEPAP");    // Higher End-Expiratory Positive Airway Pressure
     STR_TR_EPAPLo = QObject::tr("Min EPAP"); // Lower Expiratory Positive Airway Pressure
     STR_TR_EPAPHi = QObject::tr("Max EPAP"); // Higher Expiratory Positive Airway Pressure
     STR_TR_IPAP = QObject::tr("IPAP");    // Inspiratory Positive Airway Pressure
