@@ -72,6 +72,7 @@ public:
         rms9_mode = -1;
         set_pressure = -1;
         epap = -1;
+        epapAuto = -1;
         max_pressure = -1;
         min_pressure = -1;
         max_epap = -1;
@@ -145,12 +146,21 @@ public:
         s_SmartStop  = -1;
         s_Comfort = -1;
 
-        ramp_pressure = -1;
+        s_RampPressure = -1;
+
+        s_EasyBreathe = -1;
+        s_RiseEnable = -1;
+        s_RiseTime = -1;
+        s_Cycle = -1;
+        s_Trigger = -1;
+        s_TiMax = -1;
+        s_TiMin = -1;
 
         date=QDate();
     }
     
     STRRecord(const STRRecord & /*copy*/) = default;
+    ~STRRecord() {};    // required to get rid of warning
 
 // All the data members
 
@@ -165,6 +175,7 @@ public:
     EventDataType max_pressure;
     EventDataType min_pressure;
     EventDataType epap;
+    EventDataType epapAuto;
     EventDataType max_ps;
     EventDataType min_ps;
     EventDataType ps;
@@ -208,7 +219,7 @@ public:
     EventDataType tgtipap95;
     EventDataType tgtipapmax;
 
-    EventDataType ramp_pressure;
+    EventDataType s_RampPressure;
     QDate date;
 
     EventDataType s_RampTime;
@@ -230,6 +241,14 @@ public:
     int s_SmartStop;
     int s_Comfort;
 
+    int s_EasyBreathe;
+    int s_RiseEnable;
+    EventDataType s_RiseTime;
+    int s_Cycle;
+    int s_Trigger;
+    EventDataType s_TiMax;
+    EventDataType s_TiMin;
+
 };
 
 
