@@ -7,6 +7,9 @@
  * License. See the file COPYING in the main directory of the source code
  * for more details. */
 
+#define TEST_MACROS_ENABLEDoff
+#include <test_macros.h>
+
 #include <QApplication>
 #include <QDir>
 #include <QDebug>
@@ -33,6 +36,7 @@
 #include "profiles.h"
 #include <algorithm>
 #include "SleepLib/schema.h"
+//#include "SleepLib/session.h"
 #include "SleepLib/day.h"
 #include "mainwindow.h"
 
@@ -161,7 +165,7 @@ bool Machine::saveSessionInfo()
         Session * sess = s.value();
         if (sess->s_first != 0) {
             out << (quint32) sess->session();
-            out << (bool)(sess->enabled());
+            out << (quint8)(sess->enabled(true));
         } else {
             qWarning() << "Machine::SaveSessionInfo discarding session" << sess->s_session
                        << "["+QDateTime::fromTime_t(sess->s_session).toString("MMM dd, yyyy hh:mm:ss")+"]"
@@ -194,9 +198,11 @@ bool Machine::loadSessionInfo()
             Session * sess = s.value();
             QHash<ChannelID, QVariant>::iterator it = sess->settings.find(SESSION_ENABLED);
 
-            bool b = true;
+            quint8 b = true;
+            b &= 0x1;
             if (it != sess->settings.end()) {
                 b = it.value().toBool();
+            } else {
             }
             sess->setEnabled(b);        // Extract from session settings and save..
         }
@@ -230,11 +236,12 @@ bool Machine::loadSessionInfo()
     in >> size;
 
     quint32 sid;
-    bool b;
+    quint8 b;
 
     for (int i=0; i< size; ++i) {
         in >> sid;
         in >> b;
+        b &= 0x1;
 
         s = sessionlist.find(sid);
 
@@ -393,8 +400,7 @@ bool Machine::AddSession(Session *s, bool allowOldSessions)
 
     if (session_length < ignore_sessions) {
         // keep the session to save importing it again, but don't add it to the day record this time
-        qDebug() << s->session() << "Ignoring short session <" << ignore_sessions
-            << "["+QDateTime::fromMSecsSinceEpoch(s->first()).toString("MMM dd, yyyy hh:mm:ss")+"]";
+        // qDebug() << s->session() << "Ignoring short session <" << ignore_sessions << "["+QDateTime::fromMSecsSinceEpoch(s->first()).toString("MMM dd, yyyy hh:mm:ss")+"]";
         return true;
     }
 
@@ -415,7 +421,6 @@ bool Machine::AddSession(Session *s, bool allowOldSessions)
         dit = day.insert(date, profile->addDay(date));
     }
     dd = dit.value();
-
     dd->addSession(s);
 
     if (combine_next_day) {
@@ -624,7 +629,7 @@ void Machine::setInfo(MachineInfo inf)
 }
 
 const QString Machine::getDataPath()
-{    
+{
     // TODO: Rework the underlying database so that file storage doesn't rely on consistent presence or absence of the serial number.
     m_dataPath = p_pref->Get("{home}/Profiles/")+profile->user->userName()+"/"+info.loadername + "_"
                  + (info.serial.isEmpty() ? hexid() : info.serial) + "/";
@@ -706,7 +711,7 @@ bool Machine::Load(ProgressDialog *progress)
         progress->setProgressValue(0);
         QApplication::processEvents();
 
-        QTime time;
+        QElapsedTimer time;
         time.start();
         dir.setFilter(QDir::Files | QDir::Hidden | QDir::NoSymLinks);
 
@@ -899,7 +904,7 @@ const int summaryxml_version=1;
 
 bool Machine::LoadSummary(ProgressDialog * progress)
 {
-    QTime time;
+    QElapsedTimer time;
     time.start();
     QString filename = getDataPath() + summaryFileName + ".gz";
 
@@ -1022,7 +1027,7 @@ bool Machine::LoadSummary(ProgressDialog * progress)
 //      if ((cnt % 100) == 0) {
 //          progress->setValue(cnt);
 //          //QApplication::processEvents();
-//      } 
+//      }
 *****************************************************************/
         Session * sess = it.value();
         if ( ! AddSession(sess, true)) {
@@ -1083,7 +1088,7 @@ bool Machine::SaveSummaryCache()
         el.setAttribute("id", (quint32)sess->session());
         el.setAttribute("first", sess->realFirst());
         el.setAttribute("last", sess->realLast());
-        el.setAttribute("enabled", sess->enabled() ? "1" : "0");
+        el.setAttribute("enabled", sess->enabled(true) ? "1" : "0");
         el.setAttribute("events", sess->summaryOnly() ? "0" : "1");
 
         QHash<ChannelID, QVector<EventList *> >::iterator ev;
