@@ -159,7 +159,7 @@ class Machine
 
 
     //! \brief Returns the machineID as a lower case hexadecimal string
-    QString hexid() { return QString().sprintf("%08lx", m_id); }
+    QString hexid() { return QString::asprintf("%08lx", m_id); }
 
 
     //! \brief Unused, increments the most recent sessionID
