@@ -7,6 +7,9 @@
  * License. See the file COPYING in the main directory of the source code
  * for more details. */
 
+#define TEST_MACROS_ENABLEDoff
+#include <test_macros.h>
+
 #include <QString>
 #include <QDateTime>
 #include <QDir>
@@ -156,7 +159,7 @@ void Profile::addLock()
     QFile lockfile(p_path+"lockfile");
     lockfile.open(QFile::WriteOnly);
     QByteArray ba;
-    ba.append(QHostInfo::localHostName());
+    ba.append(QHostInfo::localHostName().toUtf8());
     lockfile.write(ba);
     lockfile.close();
 }
@@ -1046,6 +1049,8 @@ Profile *Get()
     return profiles[getUserName()];;
 }
 
+//profiles.xml is never read so it does not need to be saved.
+#if 0
 void saveProfileList()
 {
     QString filename = p_pref->Get("{home}/profiles.xml");
@@ -1075,6 +1080,7 @@ void saveProfileList()
 
     file.close();
 }
+#endif
 
 int CleanupProfile(Profile *prof)
 {
@@ -1087,7 +1093,11 @@ int CleanupProfile(Profile *prof)
                 << STR_AS_AntiAliasing << STR_AS_LineThickness << STR_AS_UsePixmapCaching
                 << STR_AS_SquareWave << STR_AS_RightPanelWidth << STR_US_TooltipTimeout
                 << STR_AS_Animations << STR_AS_AllowYAxisScaling << STR_AS_GraphTooltips
-                << STR_CS_UserEventPieChart << STR_AS_OverlayType << STR_AS_OverviewLinechartMode;
+                << STR_CS_UserEventPieChart << STR_AS_OverlayType
+                #ifndef REMOVE_FITNESS
+                << STR_AS_OverviewLinechartMode
+                #endif
+                ;
 
     int cnt = 0;
     for (auto & prf :migrateList) {
@@ -1150,7 +1160,8 @@ void Scan()
         p_pref->Save();
     }
     // Update profiles.xml for mobile version
-    saveProfileList();
+    // profiles.xml is never read so it does not need to be saved.
+    // saveProfileList();
 }
 
 
@@ -1986,7 +1997,8 @@ const quint16 chandata_version = 1;
 void Profile::saveChannels()
 {
     // First save the XML version for Mobile versions
-    schema::channel.Save(Get("{DataFolder}/") + "channels.xml");
+    // Profile/User/chanels.xml is not read so it does not need to be saved
+    // schema::channel.Save(Get("{DataFolder}/") + "channels.xml");
 
     QString filename = Get("{DataFolder}/") + "channels.dat";
     QFile f(filename);
@@ -2097,7 +2109,7 @@ void Profile::loadChannels()
 
         if (chan->isNull()) {
             qDebug() << "loadChannels has no idea about channel" << name;
-            if (in.atEnd()) return;
+            if (in.atEnd()) break;
             continue;
         }
         chan->setEnabled(enabled);
@@ -2118,8 +2130,14 @@ void Profile::loadChannels()
         chan->setUpperThresholdColor(upperThresholdColor);
 
         chan->setShowInOverview(showOverview);
-        if (in.atEnd()) return;
+        if (in.atEnd()) break;
     }
-
     f.close();
+    resetOxiChannelPref();
 }
+
+void Profile::resetOxiChannelPref() {
+    schema::channel[OXI_Pulse].setLowerThreshold(oxi->flagPulseBelow());
+    schema::channel[OXI_Pulse].setUpperThreshold(oxi->flagPulseAbove());
+    schema::channel[OXI_SPO2].setLowerThreshold(oxi->oxiDesaturationThreshold());
+};
