@@ -113,7 +113,7 @@ class Session
     }
 
     //! \brief Returns whether or not session is being used.
-    inline bool enabled() const { return s_enabled; }
+    bool enabled(bool realValues=false) const;
 
     //! \brief Sets whether or not session is being used.
     void setEnabled(bool b);
@@ -132,7 +132,8 @@ class Session
 
     //! \brief Return the millisecond length of this session
     qint64 length() {
-        return s_last - s_first;
+        qint64 duration=s_last - s_first;
+        return duration<0?0:duration;
 //        qint64 t;
 //        int size = m_slices.size();
 //        if (size == 0) {
@@ -362,7 +363,7 @@ class Session
     EventDataType calcMiddle(ChannelID code);
     EventDataType calcMax(ChannelID code);
     EventDataType calcPercentile(ChannelID code);
-    
+
     //! \brief Returns true if the channel has events loaded, or a record of a count for when they are not
     bool channelExists(ChannelID name);
 
@@ -417,15 +418,6 @@ class Session
     //! \brief Completely purges Session from memory and disk.
     bool Destroy();
 
-    void wipeSummary() {
-        s_first = s_last = 0;
-        s_enabled = true;
-        m_cph.clear();
-        m_sum.clear();
-        m_cnt.clear();
-    }
-
-
     QString eventFile() const;
 
     //! \brief Returns DeviceType for this session
@@ -433,7 +425,7 @@ class Session
 
 
 
-#ifdef SESSION_DEBUG 
+#ifdef SESSION_DEBUG
     QStringList session_files;
 #endif
 
@@ -456,7 +448,7 @@ protected:
 
     bool s_summary_loaded;
     bool s_events_loaded;
-    bool s_enabled;
+    quint8 s_enabled;
 
     // for debugging
     bool destroyed;
