@@ -10,7 +10,6 @@
 #ifndef DAILY_H
 #define DAILY_H
 
-
 #include <QMenu>
 #include <QAction>
 #include <QWidget>
@@ -25,17 +24,20 @@
 
 #include "SleepLib/profiles.h"
 #include "mainwindow.h"
-#include "Graphs/gSummaryChart.h"
 #include "Graphs/gGraphView.h"
 #include "Graphs/gLineChart.h"
 #include "sessionbar.h"
 #include "mytextbrowser.h"
+#include "saveGraphLayoutSettings.h"
+
 
 namespace Ui {
     class Daily;
 }
 
 class MainWindow;
+class DailySearchTab;
+class gFlagsGroup;
 
 
 /*! \class Daily
@@ -138,6 +140,15 @@ public:
 
     //void populateSessionWidget();
 
+    void showAllGraphs(bool show);
+    void showGraph(int index,bool show, bool updateGraph=true);
+    void showAllEvents(bool show);
+    void showEvent(int index,bool show, bool updateEvent=true);
+    void updateEventsCombo(Day*);
+    QString STR_HIDE_ALL_EVENTS =QString(tr("Hide All Events"));
+    QString STR_SHOW_ALL_EVENTS =QString(tr("Show All Events"));
+    QString STR_HIDE_ALL_GRAPHS =QString(tr("Hide All Graphs"));
+    QString STR_SHOW_ALL_GRAPHS =QString(tr("Show All Graphs"));
 
 public slots:
     void on_LineCursorUpdate(double time);
@@ -230,7 +241,9 @@ private slots:
         */
     void on_bookmarkTable_itemChanged(QTableWidgetItem *item);
 
+    void on_graphCombo_activated(int index);
 
+#ifndef REMOVE_FITNESS
     /*! \fn on_ouncesSpinBox_valueChanged(int arg1);
         \brief Called when the zombie slider has been moved.. Updates the BMI dislpay and journal objects.
 
@@ -238,9 +251,7 @@ private slots:
         */
     void on_ZombieMeter_valueChanged(int value);
 
-    void on_graphCombo_activated(int index);
-
-    void on_toggleGraphs_clicked(bool checked);
+    void set_ZombieMeterLabel();
 
     /*! \fn on_weightSpinBox_editingFinished();
         \brief Called when weight has changed.. Updates the BMI dislpay and journal objects.
@@ -260,17 +271,20 @@ private slots:
     void on_ouncesSpinBox_valueChanged(int arg1);
 
     void on_weightSpinBox_valueChanged(double arg1);
+#endif
+
+    bool rejectToggleSessionEnable(Session * sess);
 
     void doToggleSession(Session *);
 
     void on_eventsCombo_activated(int index);
 
-    void on_toggleEvents_clicked(bool checked);
-
     void updateGraphCombo();
 
     void on_splitter_2_splitterMoved(int pos, int index);
 
+    void on_layout_clicked();
+
 protected:
     virtual void showEvent(QShowEvent *);
 
@@ -311,9 +325,10 @@ private:
 
     void setGraphText();
     void setFlagText();
+    DailySearchTab* dailySearchTab = nullptr;
 
 
-    QString getLeftAHI (Day * day);
+    //QString getLeftAHI (Day * day);
     QString getSessionInformation(Day *);
     QString getMachineSettings(Day *);
     QString getStatisticsInfo(Day *);
@@ -321,7 +336,7 @@ private:
     QString getOximeterInformation(Day *);
     QString getEventBreakdown(Day *);
     QString getPieChart(float values, Day *);
-    QString getIndicesAndPie(Day *, float hours, bool isBrick);
+    //QString getIndicesAndPie(Day *, float hours, bool isBrick);
     QString getSleepTime(Day *);
     QString getLeftSidebar (bool honorPieChart);
 
@@ -338,6 +353,8 @@ private:
     QMenu *show_graph_menu;
 
     gGraphView *GraphView,*snapGV;
+    gGraph* sleepFlags;
+    gFlagsGroup* sleepFlagsGroup;
     MyScrollBar *scrollbar;
     QHBoxLayout *layout;
     QLabel *emptyToggleArea;
@@ -354,9 +371,15 @@ private:
 
     gLineChart *leakchart;
 
+    const int eventTypeStart = QTreeWidgetItem::UserType+1;
+    const int eventTypeEnd   = QTreeWidgetItem::UserType+2;
+
+#ifndef REMOVE_FITNESS
     bool ZombieMeterMoved;
+#endif
     bool BookmarksChanged;
 
+    SaveGraphLayoutSettings* saveGraphLayoutSettings=nullptr;
 };
 
 #endif // DAILY_H
