@@ -7,12 +7,17 @@
  * License. See the file COPYING in the main directory of the source code
  * for more details. */
 
+#define TEST_MACROS_ENABLEDoff
+#include <test_macros.h>
+
+
 #include <QHostInfo>
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QResource>
 #include <QProgressBar>
 #include <QTimer>
+#include <QElapsedTimer>
 #include <QSettings>
 #include <QPixmap>
 #include <QDesktopWidget>
@@ -33,9 +38,13 @@
 #include <QScreen>
 #include <QStorageInfo>
 #include <cmath>
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+#include <QRandomGenerator>
+#endif
 
 #include "common_gui.h"
 #include "version.h"
+#include "SleepLib/appsettings.h"       // defines for REMSTAR_M_SUPPORT
 
 
 // Custom loaders that don't autoscan..
@@ -108,7 +117,7 @@ MainWindow::MainWindow(QWidget *parent) :
 //        systraymenu->addAction(tr("Check for &Updates"), this, SLOT(on_actionCheck_for_Updates_triggered()));
         systraymenu->addSeparator();
         systraymenu->addAction(tr("E&xit"), this, SLOT(close()));
-        
+
 //      systraymenu = nullptr;
     } else { // if not available, the messages will popup in the taskbar
         qDebug() << "No System Tray menues";
@@ -132,6 +141,7 @@ QString MainWindow::getMainWindowTitle()
 void MainWindow::SetupGUI()
 {
     setupRunning = true;
+
     setWindowTitle(getMainWindowTitle());
 
 #ifdef Q_OS_MAC
@@ -168,48 +178,7 @@ void MainWindow::SetupGUI()
     m_restartRequired = false;
     // Initialize Status Bar objects
 
-    QTextCharFormat format = ui->statStartDate->calendarWidget()->weekdayTextFormat(Qt::Saturday);
-    format.setForeground(QBrush(Qt::black, Qt::SolidPattern));
-    Qt::DayOfWeek dow=firstDayOfWeekFromLocale();
-    ui->statStartDate->calendarWidget()->setWeekdayTextFormat(Qt::Saturday, format);
-    ui->statStartDate->calendarWidget()->setWeekdayTextFormat(Qt::Sunday, format);
-    ui->statStartDate->calendarWidget()->setVerticalHeaderFormat(QCalendarWidget::NoVerticalHeader);
-    ui->statStartDate->calendarWidget()->setFirstDayOfWeek(dow);
-    ui->statEndDate->calendarWidget()->setWeekdayTextFormat(Qt::Saturday, format);
-    ui->statEndDate->calendarWidget()->setWeekdayTextFormat(Qt::Sunday, format);
-    ui->statEndDate->calendarWidget()->setVerticalHeaderFormat(QCalendarWidget::NoVerticalHeader);
-    ui->statEndDate->calendarWidget()->setFirstDayOfWeek(dow);
-
-    ui->statEndDate->setVisible(false);
-    ui->statStartDate->setVisible(false);
-
-//    ui->reportModeRange->setVisible(false);
-    int srm = 0;
-    if (p_profile) {
-        srm = p_profile->general->statReportMode();
-    }
-
-    switch(srm) {
-        case 0:
-            ui->reportModeStandard->setChecked(true);
-            break;
-        case 1:
-            ui->reportModeMonthly->setChecked(true);
-            break;
-        case 2:
-            ui->reportModeRange->setChecked(true);
-            ui->statEndDate->setVisible(true);
-            ui->statStartDate->setVisible(true);
-            break;
-        default:
-            if (p_profile) {
-                p_profile->general->setStatReportMode(0);
-            }
-            break;
-    }
-    if (!AppSetting->showDebug()) {
-        ui->logText->hide();
-    }
+    init_reportModeUi() ;
 
 #ifdef Q_OS_MAC
     //p_profile->appearance->setAntiAliasing(false);
@@ -228,16 +197,26 @@ void MainWindow::SetupGUI()
     ui->tabWidget->setCurrentWidget(profileSelector);   // setting this to daily shows the cube during loading..
     ui->tabWidget->setTabEnabled(1, false);             // this should be the Statistics tab
 
-    ui->toolBox->setCurrentIndex(0);
+    // toolbox is the right sidebar that contain the Navigation, bookmark , and Records tabs.
+    // Navigation has offset 0
+    // Bookmarks  has offset 1
+    // Records    has offset 2
+    ui->toolBox->setCurrentIndex(2);
     bool b = AppSetting->rightSidebarVisible();
     ui->action_Sidebar_Toggle->setChecked(b);
     ui->toolBox->setVisible(b);
 
+    bool oldState = ui->actionShowPersonalData->blockSignals(true);
     ui->actionShowPersonalData->setChecked(AppSetting->showPersonalData());
+    ui->actionShowPersonalData->blockSignals(oldState);
 
+    oldState = ui->actionPie_Chart->blockSignals(true);
     ui->actionPie_Chart->setChecked(AppSetting->showPieChart());
+    ui->actionPie_Chart->blockSignals(oldState);
 
+    oldState = ui->actionDaily_Calendar->blockSignals(true);
     ui->actionDaily_Calendar->setChecked(AppSetting->calendarVisible());
+    ui->actionDaily_Calendar->blockSignals(oldState);
 
     on_tabWidget_currentChanged(0);
 
@@ -245,7 +224,11 @@ void MainWindow::SetupGUI()
     ui->actionImport_RemStar_MSeries_Data->setVisible(false);
 #endif
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QRandomGenerator(QDateTime::currentDateTime().toTime_t());
+#else
     qsrand(QDateTime::currentDateTime().toTime_t());
+#endif
 
     QList<int> a;
 
@@ -263,6 +246,12 @@ void MainWindow::SetupGUI()
     ui->actionReport_a_Bug->setVisible(false);  // remove this once we actually implement it
     ui->actionExport_Review->setVisible(false);  // remove this once we actually implement it
 
+    reset_reportModeUi() ;
+    if (!AppSetting->showDebug()) {
+        ui->logText->hide();
+    }
+
+
 #ifndef helpless
     help = new Help(this);
     ui->tabWidget->addTab(help, tr("Help Browser"));
@@ -285,7 +274,7 @@ void MainWindow::closeEvent(QCloseEvent * event)
             QThread::msleep(1000);
             QApplication::processEvents();
         }
-        schema::channel.Save();
+        // Profile/User/chanels.xml is not read so it does not need to be saved//schema::channel.Save();
         if (p_profile) {
             CloseProfile();
         }
@@ -390,7 +379,7 @@ void MainWindow::PopulatePurgeMenu()
         Machine *mach = machines.at(i);
         addMachineToMenu(mach, ui->menu_Rebuild_CPAP_Data);
     }
-    
+
     // Add any imported device (except the built-in journal) to the purge menu.
     machines = p_profile->GetMachines();
     for (int i=0; i < machines.size(); ++i) {
@@ -452,6 +441,7 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
             return false;
         }
     }
+
     prof = profileSelector->SelectProfile(profileName, skippassword);  // asks for the password and updates stuff in profileSelector tab
     if (!prof) {
         return false;
@@ -461,6 +451,7 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
     // Check Lockfile
     QString lockhost = prof->checkLock();
 
+
     if (!lockhost.isEmpty()) {
         if (lockhost.compare(QHostInfo::localHostName()) != 0) {
             if (QMessageBox::warning(nullptr, STR_MessageBox_Warning,
@@ -476,7 +467,6 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
     }
 
     p_profile = prof;
-
     ProgressDialog * progress = new ProgressDialog(this);
 
     progress->setMessage(QObject::tr("Loading profile \"%1\"...").arg(profileName));
@@ -519,6 +509,14 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
     }
 
     p_profile->LoadMachineData(progress);
+
+    if (!p_profile->LastDay(MT_CPAP).isValid() ) { // quick test if new profile or not.
+        // Override default value of clinicalMode if new profile.
+        // Allows permissiveMode (not clinicalMode) to be the default value for existing profiles.
+        p_profile->cpap->setClinicalMode(true);
+    }
+    m_clinicalMode = p_profile->cpap->clinicalMode();
+
     progress->setMessage(tr("Loading profile \"%1\"").arg(profileName));
 
     // Show the logo?
@@ -527,8 +525,6 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
 
     QApplication::processEvents();
 
-    ui->statStartDate->setDate(p_profile->FirstDay());
-    ui->statEndDate->setDate(p_profile->LastDay());
 
     // Reload everything profile related
     if (daily) {
@@ -554,6 +550,8 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
 
     // Should really create welcome and statistics here, but they need redoing later anyway to kill off webkit
     ui->tabWidget->setCurrentIndex(AppSetting->openTabAtStart());
+
+    p_profile->general->setStatReportMode(STAT_MODE_STANDARD);
     GenerateStatistics();
     PopulatePurgeMenu();
 
@@ -574,33 +572,6 @@ bool MainWindow::OpenProfile(QString profileName, bool skippassword)
     ui->tabWidget->setTabEnabled(3, !noMachines);       // overview, STR_TR_Overview);
     ui->tabWidget->setTabEnabled(4, !noMachines);       // statistics, STR_TR_Statistics);
 
-    int srm = 0;
-    if (p_profile) {
-        srm = p_profile->general->statReportMode();
-    }
-
-    switch (srm) {
-        case 0:
-            ui->reportModeStandard->setChecked(true);
-            ui->statEndDate->setVisible(false);
-            ui->statStartDate->setVisible(false);
-            break;
-        case 1:
-            ui->reportModeMonthly->setChecked(true);
-            ui->statEndDate->setVisible(false);
-            ui->statStartDate->setVisible(false);
-            break;
-        case 2:
-            ui->reportModeRange->setChecked(true);
-            ui->statEndDate->setVisible(true);
-            ui->statStartDate->setVisible(true);
-            break;
-        default:
-            if (p_profile) {
-                p_profile->general->setStatReportMode(0);
-            }
-            break;
-    }
 
     progress->close();
     delete progress;
@@ -848,14 +819,14 @@ QStringList getDriveList()
 #endif
     foreach (const QStorageInfo &storage, QStorageInfo::mountedVolumes()) {
         if (storage.isValid() && storage.isReady()) {
-#ifdef DEBUG_SDCARD            
+#ifdef DEBUG_SDCARD
             if (storage.fileSystemType() != "tmpfs") {      // Don't show all the Linux tmpfs mount points!
                 qDebug() << "Device:" << storage.device();
                 qDebug() << "    Path:" << storage.rootPath();
                 qDebug() << "    Name:" << storage.name();     // ...
                 qDebug() << "    FS Type:" << storage.fileSystemType();
             }
-#endif            
+#endif
             if (storage.fileSystemType() == VFAT) {
                 qDebug() << "Adding" << storage.name() << "on" << storage.rootPath() << "to drivelist";
                 drivelist.append(storage.rootPath());
@@ -883,7 +854,7 @@ QStringList getDriveList()
             drivelist.append("CROSTINI");
         }
     }
-#endif    
+#endif
     return drivelist;
 }
 
@@ -903,7 +874,7 @@ QList<ImportPath> MainWindow::detectCPAPCards()
     QString lastpath = (*p_profile)[STR_PREF_LastCPAPPath].toString();
 
     QList<MachineLoader *>loaders = GetLoaders(MT_CPAP);
-    QTime time;
+    QElapsedTimer time;
     time.start();
 
     // Create dialog
@@ -1030,7 +1001,7 @@ QList<ImportPath> MainWindow::selectCPAPDataCards(const QString & prompt, bool a
 
     QList<MachineLoader *>loaders = GetLoaders(MT_CPAP);
 
-    QTime time;
+    QElapsedTimer time;
     time.start();
 
 
@@ -1134,16 +1105,23 @@ QList<ImportPath> MainWindow::selectCPAPDataCards(const QString & prompt, bool a
         }
 
 
+        bool found=false;
         for (int i = 0; i < w.selectedFiles().size(); i++) {
             Q_FOREACH(MachineLoader * loader, loaders) {
                 if (loader->Detect(w.selectedFiles().at(i))) {
+                    found=true;
                     datacards.append(ImportPath(w.selectedFiles().at(i), loader));
                     break;
                 }
             }
         }
+        if (!found) {
+            QMessageBox msgBox ( QMessageBox::Information , tr("OSCAR Information") , tr("No supported data was found") , QMessageBox::Ok ) ;
+            msgBox.setInformativeText(w.selectedFiles().at(0));
+            msgBox.exec();
+        }
     }
-    
+
     return datacards;
 }
 
@@ -1367,6 +1345,12 @@ void MainWindow::on_action_Preferences_triggered()
 
         setApplicationFont();
 
+
+        if (m_clinicalMode != p_profile->cpap->clinicalMode() ) {
+            m_clinicalMode = p_profile->cpap->clinicalMode(); ;
+            reloadProfile();
+        };
+
         if (daily) {
             daily->RedrawGraphs();
         }
@@ -1382,6 +1366,8 @@ void MainWindow::on_action_Preferences_triggered()
         if (profileSelector)
             profileSelector->updateProfileList();
 
+        GenerateStatistics();
+
 // These attempts to update calendar after a change to application font do NOT work, and I can find no QT documentation suggesting
 // that changing the font after Calendar is created is even possible.
 //        qDebug() << "application font family set to" << QApplication::font().family() << "and font" << QApplication::font();
@@ -1683,7 +1669,7 @@ void MainWindow::RestartApplication(bool force_login, QString cmdline)
 
     if (QProcess::startDetached("/usr/bin/open", args)) {
         QApplication::instance()->exit();
-    } else { 
+    } else {
         QMessageBox::warning(nullptr, STR_MessageBox_Error,
             tr("If you can read this, the restart command didn't work. You will have to do it yourself manually."), QMessageBox::Ok);
     }
@@ -1710,7 +1696,7 @@ void MainWindow::RestartApplication(bool force_login, QString cmdline)
         QApplication::instance()->exit();
 
 //        ::exit(0);
-    } else { 
+    } else {
         QMessageBox::warning(nullptr,  STR_MessageBox_Error,
             tr("If you can read this, the restart command didn't work. You will have to do it yourself manually."), QMessageBox::Ok);
     }
@@ -1933,7 +1919,7 @@ void MainWindow::on_actionPurgeMachine(QAction *action)
                                   "<font size=+2>you will lose this device's data <b>permanently</b>!</font>") + "</p>";
     }
 
-    if (QMessageBox::question(this, STR_MessageBox_Warning, 
+    if (QMessageBox::question(this, STR_MessageBox_Warning,
             "<p><b>"+STR_MessageBox_Warning+":</b> "  +
             tr("You are about to <font size=+2>obliterate</font> OSCAR's device database for the following device:</p>") +
             "<p><font size=+2>" + machname + "</font></p>" +
@@ -1996,14 +1982,14 @@ void MainWindow::purgeMachine(Machine * mach)
             tr("A file permission error caused the purge process to fail; you will have to delete the following folder manually:") +
             "\n\n" + QDir::toNativeSeparators(mach->getDataPath()), QMessageBox::Ok, QMessageBox::Ok);
 
-        if (overview) 
+        if (overview)
             overview->ReloadGraphs();
 
         if (daily) {
             daily->clearLastDay(); // otherwise Daily will crash
             daily->ReloadGraphs();
         }
-        if (welcome) 
+        if (welcome)
             welcome->refreshPage();
 
         //GenerateStatistics();
@@ -2011,7 +1997,7 @@ void MainWindow::purgeMachine(Machine * mach)
     }
 
 
-    if (overview) 
+    if (overview)
         overview->ReloadGraphs();
     QFile rxcache(p_profile->Get("{" + STR_GEN_DataFolder + "}/RXChanges.cache" ));
     rxcache.remove();
@@ -2319,7 +2305,7 @@ void MainWindow::importNonCPAP(MachineLoader &loader)
             QCoreApplication::processEvents();
         }
         QString name = loader.loaderName();
-        
+
         ImportUI importui(p_profile);
         ImportContext* ctx = new ProfileImportContext(p_profile);
         loader.SetContext(ctx);
@@ -2374,22 +2360,12 @@ void MainWindow::on_actionImport_Viatom_Data_triggered()
 
 void MainWindow::GenerateStatistics()
 {
-    QDate first = p_profile->FirstDay();
-    QDate last = p_profile->LastDay();
-    ui->statStartDate->setMinimumDate(first);
-    ui->statStartDate->setMaximumDate(last);
-
-    ui->statEndDate->setMinimumDate(first);
-    ui->statEndDate->setMaximumDate(last);
+    reset_reportModeUi() ;
 
     Statistics stats;
     QString htmlStats = stats.GenerateHTML();
     QString htmlRecords = stats.UpdateRecordsBox();
 
-    bool brange = (p_profile->general->statReportMode() == 2);
-    ui->statEndDate->setVisible(brange);
-    ui->statStartDate->setVisible(brange);
-
     updateFavourites();
 
     setStatsHTML(htmlStats);
@@ -2429,22 +2405,92 @@ void MainWindow::on_statisticsButton_clicked()
     }
 }
 
+void MainWindow::init_reportModeUi() 
+{
+    QTextCharFormat format = ui->statStartDate->calendarWidget()->weekdayTextFormat(Qt::Saturday);
+    format.setForeground(QBrush(Qt::black, Qt::SolidPattern));
+    Qt::DayOfWeek dow=firstDayOfWeekFromLocale();
+    ui->statStartDate->blockSignals(true);
+    ui->statEndDate->blockSignals(true);
+    ui->statStartDate->calendarWidget()->setWeekdayTextFormat(Qt::Saturday, format);
+    ui->statStartDate->calendarWidget()->setWeekdayTextFormat(Qt::Sunday, format);
+    ui->statStartDate->calendarWidget()->setVerticalHeaderFormat(QCalendarWidget::NoVerticalHeader);
+    ui->statStartDate->calendarWidget()->setFirstDayOfWeek(dow);
+    ui->statEndDate->calendarWidget()->setWeekdayTextFormat(Qt::Saturday, format);
+    ui->statEndDate->calendarWidget()->setWeekdayTextFormat(Qt::Sunday, format);
+    ui->statEndDate->calendarWidget()->setVerticalHeaderFormat(QCalendarWidget::NoVerticalHeader);
+    ui->statEndDate->calendarWidget()->setFirstDayOfWeek(dow);
+    ui->statStartDate->blockSignals(false);
+    ui->statEndDate->blockSignals(false);
+}
+
+void MainWindow::reset_reportModeUi()
+{
+    Statistics::updateReportDate();
+    int mode = STAT_MODE_STANDARD;
+    ui->statStartDate->blockSignals(true);
+    ui->statEndDate->blockSignals(true);
+    if (p_profile) {
+        mode = p_profile->general->statReportMode();
+
+        QDate first = p_profile->FirstDay();
+        QDate last = p_profile->LastDay();
+        ui->statStartDate->setMinimumDate(first);
+        ui->statStartDate->setMaximumDate(last);
+        ui->statEndDate->setMinimumDate(first);
+        ui->statEndDate->setMaximumDate(last);
+    }
+    switch (mode) {
+        default:
+        case STAT_MODE_STANDARD:
+            {
+            ui->reportModeStandard->setChecked(true);
+            ui->statEndDate->setVisible(true);
+            ui->statStartDate->setVisible(false);
+            ui->statEnableEndDisplay->setVisible(true);
+            if (p_profile) {
+                ui->statEndDate->setDate(p_profile->general->statReportDate());
+            }
+            }
+            break;
+        case STAT_MODE_MONTHLY:
+            ui->statStartDate->setVisible(false);
+            ui->statEndDate->setVisible(true);
+            ui->reportModeMonthly->setChecked(true);
+
+            ui->statEnableEndDisplay->setVisible(true);
+            if (p_profile) {
+                ui->statEndDate->setDate(p_profile->general->statReportDate());
+            }
+            break;
+        case STAT_MODE_RANGE:
+            ui->reportModeRange->setChecked(true);
+            ui->statStartDate->setVisible(true);
+            ui->statEndDate->setVisible(true);
+            ui->statEnableEndDisplay->setVisible(false);
+            if (p_profile) {
+                ui->statStartDate->setDate( p_profile->general->statReportRangeStart());
+                ui->statEndDate->setDate( p_profile->general->statReportRangeEnd());
+            }
+            break;
+    }
+    ui->statStartDate->blockSignals(false);
+    ui->statEndDate->blockSignals(false);
+    return;
+};
+
 void MainWindow::on_reportModeMonthly_clicked()
 {
-    ui->statStartDate->setVisible(false);
-    ui->statEndDate->setVisible(false);
-    if (p_profile->general->statReportMode() != 1) {
-        p_profile->general->setStatReportMode(1);
+    if (p_profile->general->statReportMode() != STAT_MODE_MONTHLY) {
+        p_profile->general->setStatReportMode(STAT_MODE_MONTHLY);
         GenerateStatistics();
     }
 }
 
 void MainWindow::on_reportModeStandard_clicked()
 {
-    ui->statStartDate->setVisible(false);
-    ui->statEndDate->setVisible(false);
-    if (p_profile->general->statReportMode() != 0) {
-        p_profile->general->setStatReportMode(0);
+    if (p_profile->general->statReportMode() != STAT_MODE_STANDARD) {
+        p_profile->general->setStatReportMode(STAT_MODE_STANDARD);
         GenerateStatistics();
     }
 }
@@ -2452,17 +2498,19 @@ void MainWindow::on_reportModeStandard_clicked()
 
 void MainWindow::on_reportModeRange_clicked()
 {
-    ui->statStartDate->setVisible(true);
-    ui->statEndDate->setVisible(true);
-    if (p_profile->general->statReportMode() != 2) {
-        p_profile->general->setStatReportMode(2);
+    if (p_profile->general->statReportMode() != STAT_MODE_RANGE) {
+        p_profile->general->setStatReportMode(STAT_MODE_RANGE);
         GenerateStatistics();
     }
 }
 
 void MainWindow::on_statEndDate_dateChanged(const QDate &date)
 {
-    p_profile->general->setStatReportRangeEnd(date);
+    if (p_profile->general->statReportMode() == STAT_MODE_RANGE ) {
+        p_profile->general->setStatReportRangeEnd(date);
+    } else {
+        p_profile->general->setStatReportDate(date);
+    };
     GenerateStatistics();
 }
 
@@ -2495,7 +2543,7 @@ void MainWindow::on_actionPurgeCurrentDaysOximetry_triggered()
             sess->Destroy();
             delete sess;
         }
-        
+
         // We have to update the summary cache for the affected device(s),
         // otherwise OSCAR will still think this day has oximetry data at next launch.
         for (auto & mach : machines) {
@@ -2553,9 +2601,15 @@ void MainWindow::on_actionDaily_Calendar_toggled(bool visible)
 
 void MainWindow::on_actionShowPersonalData_toggled(bool visible)
 {
-    AppSetting->setShowPersonalData(visible);
-    if (!setupRunning)
-        GenerateStatistics();
+    // This uses the Prefs routines, which require p_profile to be set
+    if ( p_profile != nullptr ) {
+        AppSetting->setShowPersonalData(visible);
+        if ( ! setupRunning )
+            GenerateStatistics();
+    } else {
+        QMessageBox::information(this, "OSCAR", tr("You must select and open the profile you wish to modify"),
+                    QMessageBox::Ok);
+    }
 }
 
 #include "SleepLib/journal.h"
@@ -2604,12 +2658,12 @@ void MainWindow::on_actionCreate_Card_zip_triggered()
         QString cardPath = QDir(datacard.path).canonicalPath();
         QString filename;
         QString prefix;
-        
+
         // Loop until a valid folder is selected or the user cancels. Disallow the SD card itself!
         while (true) {
             // Note: macOS ignores this and points to OSCAR's most recently used directory for saving.
             QString folder = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
-            
+
             MachineInfo info = datacard.loader->PeekInfo(datacard.path);
             QString infostr;
             if (!info.modelnumber.isEmpty()) {
@@ -2625,7 +2679,7 @@ void MainWindow::on_actionCreate_Card_zip_triggered()
             if (filename.isEmpty()) {
                 return;  // aborted
             }
-            
+
             // Try again if the selected filename is within the SD card itself.
             QString selectedPath = QFileInfo(filename).dir().canonicalPath();
             if (selectedPath.startsWith(cardPath)) {
@@ -2642,14 +2696,14 @@ void MainWindow::on_actionCreate_Card_zip_triggered()
         if (!filename.toLower().endsWith(".zip")) {
             filename += ".zip";
         }
-        
+
         qDebug() << "Create zip of SD card:" << cardPath;
 
         ZipFile z;
         bool ok = z.Open(filename);
         if (ok) {
             ProgressDialog * prog = new ProgressDialog(this);
-            
+
             // Very full cards can sometimes take nearly a minute to scan,
             // so display the progress dialog immediately.
             prog->setMessage(tr("Calculating size..."));
@@ -2698,7 +2752,7 @@ void MainWindow::on_actionCreate_Log_zip_triggered()
     if (!filename.toLower().endsWith(".zip")) {
         filename += ".zip";
     }
-    
+
     qDebug() << "Create zip of OSCAR diagnostic logs:" << filename;
 
     ZipFile z;
@@ -2751,7 +2805,7 @@ void MainWindow::on_actionCreate_OSCAR_Data_zip_triggered()
     if (!filename.toLower().endsWith(".zip")) {
         filename += ".zip";
     }
-    
+
     qDebug() << "Create zip of OSCAR data folder:" << filename;
 
     QDir oscarData(GetAppData());
