@@ -318,6 +318,9 @@ class MainWindow : public QMainWindow
 
     void on_reportModeStandard_clicked();
 
+    void init_reportModeUi();
+    void reset_reportModeUi();
+
     void on_actionRebuildCPAP(QAction *action);
 
     void on_actionPurgeMachine(QAction *action);
@@ -404,6 +407,7 @@ private:
 //    gGraphView *SnapshotGraph;
     QString bookmarkFilter;
     bool m_restartRequired;
+    bool m_clinicalMode = false;
     volatile bool m_inRecalculation;
 
     void PopulatePurgeMenu();
