@@ -7,25 +7,8 @@
  * License. See the file COPYING in the main directory of the source code
  * for more details. */
 
-#define NEWSTUFF
-
-#define xDEBUG_FUNCTIONS
-#ifdef DEBUG_FUNCTIONS
-#include <QRegularExpression>
-#define DEBUGQ  qDebug()
-#define DEBUGL  qDebug()<<QString(basename( __FILE__)).remove(QRegularExpression("\\..*$")) << __LINE__
-#define DEBUGF  qDebug()<< QString("%1[%2]%3").arg( QString(basename( __FILE__)).remove(QRegularExpression("\\..*$")) ).arg(__LINE__).arg(__func__)
-#define DEBUGT  qDebug()<<QDateTime::currentDateTime().time().toString("hh:mm:ss.zzz")
-#define DEBUGTF qDebug()<<QDateTime::currentDateTime().time().toString("hh:mm:ss.zzz") << QString(basename( __FILE__)).remove(QRegularExpression("\\..*$")) << __LINE__ << __func__
-#define O( XX ) " " #XX ":" << XX
-#define Q( XX ) << #XX ":" << XX
-#define R( XX )
-#define OO( XX , YY ) " " #XX ":" << YY
-#define NAME( id) schema::channel[ id ].label()
-#define DATE( XX ) QDateTime::fromMSecsSinceEpoch(XX).toString("dd MMM yyyy")
-#define DATETIME( XX ) QDateTime::fromMSecsSinceEpoch(XX).toString("dd MMM yyyy hh:mm:ss.zzz")
-#endif
-
+#define TEST_MACROS_ENABLEDoff
+#include <test_macros.h>
 
 // Features enabled by conditional compilation.
 #define ENABLE_GENERAL_MODIFICATION_OF_CALENDARS
@@ -46,7 +29,11 @@
 #include "Graphs/gXAxis.h"
 #include "Graphs/gLineChart.h"
 #include "Graphs/gYAxis.h"
+#include "Graphs/gSessionTimesChart.h"
 #include "Graphs/gPressureChart.h"
+#include "Graphs/gAHIChart.h"
+#include "Graphs/gUsageChart.h"
+#include "Graphs/gTTIAChart.h"
 #include "cprogressbar.h"
 
 #include "mainwindow.h"
@@ -54,8 +41,15 @@ extern MainWindow *mainwin;
 
 
 qint64 convertDateToTimeRtn(const QDate &date,int hours,int min,int sec) {
-    return QDateTime(date).addSecs(((hours*60+min)*60)+sec).toMSecsSinceEpoch();
+    // date.startOfDay was introduced in 5.14.  ubuntu 22.04 LTS used QT5.15
+    #if QT_VERSION > QT_VERSION_CHECK(5,15,0)
+        return date.startOfDay().addSecs(((hours*60+min)*60)+sec).toMSecsSinceEpoch();
+    #else
+        // this version works in QT 5.12
+        return QDateTime(date).addSecs(((hours*60+min)*60)+sec).toMSecsSinceEpoch();
+    #endif
 }
+
 qint64 convertDateToStartTime(const QDate &date) {
     return convertDateToTimeRtn(date,0,10,0);
 }
@@ -83,8 +77,6 @@ Overview::Overview(QWidget *parent, gGraphView *shared) :
         shortformat.replace("yy", "yyyy");
     }
 
-    ui->toggleVisibility->setVisible(false);    /* get rid of tiny triangle that disables data display */
-
     ui->dateStart->setDisplayFormat(shortformat);
     ui->dateEnd->setDisplayFormat(shortformat);
 
@@ -184,6 +176,7 @@ Overview::Overview(QWidget *parent, gGraphView *shared) :
     connect(GraphView, SIGNAL(updateRange(double,double)), this, SLOT(on_RangeUpdate(double,double)));
     connect(GraphView, SIGNAL(GraphsChanged()), this, SLOT(updateGraphCombo()));
     connect(GraphView, SIGNAL(XBoundsChanged(qint64 ,qint64)), this, SLOT(on_XBoundsChanged(qint64 ,qint64)));
+    saveGraphLayoutSettings=nullptr;
 }
 
 Overview::~Overview()
@@ -205,6 +198,7 @@ Overview::~Overview()
     delete icon_off ;
     delete icon_up_down ;
     delete icon_warning ;
+    if (saveGraphLayoutSettings!=nullptr) delete saveGraphLayoutSettings;
 }
 
 void Overview::ResetFont()
@@ -280,7 +274,8 @@ void Overview::CreateAllGraphs() {
     //chartsToBeMonitored.insert(ahi,AHI);
 
     UC = createGraph(STR_GRAPH_Usage, tr("Usage"), tr("Usage\n(hours)"));
-    UC->AddLayer(uc = new gUsageChart());
+    uc = new gUsageChart();
+    UC->AddLayer(uc);
     //chartsToBeMonitored.insert(uc,UC);
 
     STG = createGraph("New Session", tr("Session Times"), tr("Session Times"),  YT_Time);
@@ -320,6 +315,11 @@ void Overview::CreateAllGraphs() {
                 G->AddLayer(sc);
                 chartsToBeMonitored.insert(sc,G);
             } else if (chan->type() == schema::WAVEFORM) {
+                if ((code==CPAP_AHI)||(code==CPAP_Pressure) ) {
+                    DEBUGF O("SKIPPING") NAME(code) Q(code);
+                    //skip if channel is for AHI.
+                    continue;
+                }
                 sc= new gSummaryChart(code, chan->machtype());
                 G->AddLayer(sc);
                 chartsToBeMonitored.insert(sc,G);
@@ -328,30 +328,34 @@ void Overview::CreateAllGraphs() {
                 sc->addCalc(code, ST_CPH, schema::channel[code].defaultColor());
                 G->AddLayer(sc);
                 chartsToBeMonitored.insert(sc,G);
-            } 
+            }
             if (sc!= nullptr) {
                 sc ->reCalculate();
             }
         } // if showInOverview()
     } // for chit
-    // Note The following don not use gSummaryChart. They use SummaryChart instead. and can not be monitored.
+    #ifndef REMOVE_FITNESS
+    /* To enable these changes:   change the REMOTE_FITNESS define in appsettings.h */
+
+    // Note The following do not use gSummaryChart. They use gOverviewGraph instead. and can not be monitored.
     WEIGHT = createGraph(STR_GRAPH_Weight, STR_TR_Weight, STR_TR_Weight, YT_Weight);
-    weight = new SummaryChart("Weight", GT_LINE);
+    weight = new gOverviewGraph("Weight", GT_LINE);
     weight->setMachineType(MT_JOURNAL);
     weight->addSlice(Journal_Weight, QColor("black"), ST_SETAVG);
     WEIGHT->AddLayer(weight);
 
     BMI = createGraph(STR_GRAPH_BMI, STR_TR_BMI, tr("Body\nMass\nIndex"));
-    bmi = new SummaryChart("BMI", GT_LINE);
+    bmi = new gOverviewGraph("BMI", GT_LINE);
     bmi->setMachineType(MT_JOURNAL);
     bmi->addSlice(Journal_BMI, QColor("black"), ST_SETAVG);
     BMI->AddLayer(bmi);
 
-    ZOMBIE = createGraph(STR_GRAPH_Zombie, STR_TR_Zombie, tr("How you felt\n(0-10)"));
-    zombie = new SummaryChart("Zombie", GT_LINE);
+    ZOMBIE = createGraph(STR_GRAPH_Zombie, STR_TR_Zombie, tr("How you felt\n(1-10)"));
+    zombie = new gOverviewGraph("Feeling", GT_LINE);
     zombie->setMachineType(MT_JOURNAL);
     zombie->addSlice(Journal_ZombieMeter, QColor("black"), ST_SETAVG);
     ZOMBIE->AddLayer(zombie);
+    #endif
 
     connectgSummaryCharts();
 }
@@ -395,7 +399,7 @@ gGraph *Overview::createGraph(QString code, QString name, QString units, YTicker
 
     switch (yttype) {
     case YT_Time:
-        yt = new gYAxisTime(true); // Time scale
+        yt = new gYAxisTime(false); // Time scale false=24hourFormat
         break;
 
     case YT_Weight:
@@ -455,12 +459,25 @@ void Overview::setGraphText () {
             if (!g->visible()) {
                 numOff++;
             }
+            //DEBUGFW  Q(numTotal) Q(numOff)  Q(g->name());
         }
     }
     ui->graphCombo->setItemIcon(0, numOff ? *icon_warning : *icon_up_down);
     QString graphText;
-    if (numOff == 0) graphText = QObject::tr("%1 Charts").arg(numTotal);
-    else             graphText = QObject::tr("%1 of %2 Charts").arg(numTotal-numOff).arg(numTotal);
+    int lastIndex = ui->graphCombo->count()-1;
+
+    if (numOff == 0) {
+        // all graphs are shown
+        graphText = QObject::tr("%1 Graphs").arg(numTotal);
+        ui->graphCombo->setItemText(lastIndex,STR_HIDE_ALL_GRAPHS);
+    } else {
+        // some graphs are hidden
+        graphText = QObject::tr("%1 of %2 Graphs").arg(numTotal-numOff).arg(numTotal);
+        if (numOff == numTotal) {
+            // all graphs are hidden
+            ui->graphCombo->setItemText(lastIndex,STR_SHOW_ALL_GRAPHS);
+        }
+    }
     ui->graphCombo->setItemText(0, graphText);
 }
 
@@ -469,7 +486,7 @@ void Overview::updateGraphCombo()
     ui->graphCombo->clear();
     gGraph *g;
 
-    ui->graphCombo->addItem(*icon_up_down, tr("10 of 10 Charts"), true); // Translation only to define space required
+    ui->graphCombo->addItem(*icon_up_down, "", true); 
     for (int i = 0; i < GraphView->size(); i++) {
         g = (*GraphView)[i];
 
@@ -481,7 +498,7 @@ void Overview::updateGraphCombo()
             ui->graphCombo->addItem(*icon_off, g->title(), false);
         }
     }
-
+    ui->graphCombo->addItem(*icon_on,STR_HIDE_ALL_GRAPHS,true);
     ui->graphCombo->setCurrentIndex(0);
     setGraphText();
     updateCube();
@@ -549,10 +566,10 @@ void Overview::on_XBoundsChanged(qint64 start,qint64 end)
 
     bool largerRange=false;
     if (displayStartDate>maxRangeEndDate || minRangeStartDate>displayEndDate) {
-        // have non-overlaping ranges 
+        // have non-overlaping ranges
         // Only occurs when custom mode is switched to/from a latest mode. custom mode to/from last week.
         // All other displays expand the existing range.
-        // reset all empty flags to not empty 
+        // reset all empty flags to not empty
         largerRange=true;
         chartsEmpty = QHash<gSummaryChart*, gGraph*>( chartsToBeMonitored );
         minRangeStartDate = displayStartDate;
@@ -754,7 +771,7 @@ void Overview::on_rangeCombo_activated(int index)
 
 
 DateErrorDisplay::DateErrorDisplay (Overview* overview)
-	:	m_overview(overview) 
+	:	m_overview(overview)
 {
 	m_visible=false;
 	m_timer = new QTimer();
@@ -854,7 +871,7 @@ void Overview::setRange(QDate& start, QDate& end, bool updateGraphs/*zoom*/)
     uiEndDate = end;
 
     //bool nextSamePage= start.daysTo(end)<=31;
-    bool nextSamePage= (start.year() == end.year() && start.month() == end.month()) ; 
+    bool nextSamePage= (start.year() == end.year() && start.month() == end.month()) ;
     if (samePage>0 ||nextSamePage) {
         // The widgets do not signal pageChanged on opening - since the page hasn't changed.
         // however the highlighting may need to be changed.
@@ -869,28 +886,40 @@ void Overview::setRange(QDate& start, QDate& end, bool updateGraphs/*zoom*/)
     updateGraphCombo();
 }
 
+void Overview::showGraph(int index,bool show, bool updateGraph) {
+    ui->graphCombo->setItemData(index,show,Qt::UserRole);
+    ui->graphCombo->setItemIcon(index, show ? *icon_on : *icon_off);
+    if (!updateGraph) return;
+    QString graphName = ui->graphCombo->itemText(index);
+    gGraph* graph=GraphView->findGraphTitle(graphName);
+    if (graph) graph->setVisible(show);
+}
+
+void Overview::showAllGraphs(bool show) {
+    //Skip over first button - label for comboBox
+    int lastIndex = ui->graphCombo->count()-1;
+    for (int i=1;i<lastIndex;i++) {
+        showGraph(i,show,true);
+    }
+}
+
+
 void Overview::on_graphCombo_activated(int index)
 {
-    if (index < 0) {
-        return;
-    }
-
-    if (index > 0 ) {
-        gGraph *g;
-        QString s;
-        s = ui->graphCombo->currentText();
-        bool b = !ui->graphCombo->itemData(index, Qt::UserRole).toBool();
-        ui->graphCombo->setItemData(index, b, Qt::UserRole);
-
-        if (b) {
-            ui->graphCombo->setItemIcon(index, *icon_on);
+   if (index<0) return;
+    if (index > 0) {
+        bool nextOn =!ui->graphCombo->itemData(index,Qt::UserRole).toBool();
+        int lastIndex = ui->graphCombo->count()-1;
+        if ( index == lastIndex ) {
+            // user just pressed hide show button - toggle states of the button and apply the new state
+            showAllGraphs(nextOn);
+            showGraph(index,nextOn,false);
         } else {
-            ui->graphCombo->setItemIcon(index, *icon_off);
+            showGraph(index,nextOn,true);
         }
-
-        g = GraphView->findGraphTitle(s);
-        g->setVisible(b);
+        ui->graphCombo->showPopup();
     }
+
     ui->graphCombo->setCurrentIndex(0);
     updateCube();
     setGraphText();
@@ -900,42 +929,22 @@ void Overview::on_graphCombo_activated(int index)
 void Overview::updateCube()
 {
     if ((GraphView->visibleGraphs() == 0)) {
-        ui->toggleVisibility->setArrowType(Qt::UpArrow);
-        ui->toggleVisibility->setToolTip(tr("Show all graphs"));
-        ui->toggleVisibility->blockSignals(true);
-        ui->toggleVisibility->setChecked(true);
-        ui->toggleVisibility->blockSignals(false);
-
         if (ui->graphCombo->count() > 0) {
             GraphView->setEmptyText(STR_Empty_NoGraphs);
-
         } else {
             GraphView->setEmptyText(STR_Empty_NoData);
         }
-    } else {
-        ui->toggleVisibility->setArrowType(Qt::DownArrow);
-        ui->toggleVisibility->setToolTip(tr("Hide all graphs"));
-        ui->toggleVisibility->blockSignals(true);
-        ui->toggleVisibility->setChecked(false);
-        ui->toggleVisibility->blockSignals(false);
     }
 }
 
-void Overview::on_toggleVisibility_clicked(bool checked)
-{
-    gGraph *g;
-    QString s;
-    QIcon *icon = checked ? icon_off : icon_on;
-
-    for (int i = 0; i < ui->graphCombo->count(); i++) {
-        s = ui->graphCombo->itemText(i);
-        ui->graphCombo->setItemIcon(i, *icon);
-        ui->graphCombo->setItemData(i, !checked, Qt::UserRole);
-        g = GraphView->findGraphTitle(s);
-        g->setVisible(!checked);
+void Overview::on_layout_clicked() {
+    if (!saveGraphLayoutSettings) {
+        saveGraphLayoutSettings= new SaveGraphLayoutSettings("overview",this);
+    }
+    if (saveGraphLayoutSettings) {
+        saveGraphLayoutSettings->menu(GraphView);
     }
-
-    updateCube();
-    GraphView->updateScale();
-    GraphView->redraw();
 }
+
+
+
