@@ -19,8 +19,15 @@
 #include <QTimer>
 #include "SleepLib/profiles.h"
 #include "Graphs/gGraphView.h"
+#ifndef REMOVE_FITNESS
+#include "Graphs/gOverviewGraph.h"
+#endif
 #include "Graphs/gSummaryChart.h"
-#include "Graphs/gSessionTimesChart.h"
+#include "saveGraphLayoutSettings.h"
+
+#include <QRegularExpression>
+#include <QListWidget>
+#include <QListWidgetItem>
 
 namespace Ui {
 class Overview;
@@ -96,8 +103,10 @@ class Overview : public QWidget
     gGraph *createGraph(QString code, QString name, QString units = "", YTickerType yttype = YT_Number);
     gGraph *AHI, *AHIHR, *UC, *FL, *SA, *US, *PR, *LK, *NPB, *SET, *SES, *RR, *MV, *TV, *PTB, *PULSE, *SPO2, *NLL,
            *WEIGHT, *ZOMBIE, *BMI, *TGMV, *TOTLK, *STG, *SN, *TTIA;
-    SummaryChart *bc, *sa, *us, *pr,  *set, *ses,  *ptb, *pulse, *spo2,
+#ifndef REMOVE_FITNESS
+    gOverviewGraph *bc, *sa, *us, *pr,  *set, *ses,  *ptb, *pulse, *spo2,
                  *weight, *zombie, *bmi, *ahihr, *tgmv, *totlk;
+#endif
 
     gSummaryChart * stg, *uc, *ahi, * pres, *lk, *npb, *rr, *mv, *tv, *nll, *sn, *ttia;
 
@@ -130,12 +139,12 @@ class Overview : public QWidget
 
     void on_graphCombo_activated(int index);
 
-    void on_toggleVisibility_clicked(bool checked);
-
     void on_LineCursorUpdate(double time);
     void on_RangeUpdate(double minx, double maxx);
     void setGraphText ();
 
+    void on_layout_clicked();
+
   private:
     void CreateAllGraphs();
     void timedUpdateOverview(int ms=0);
@@ -173,7 +182,7 @@ class Overview : public QWidget
     QDate displayStartDate;
     QDate displayEndDate;
 
-    // min / max dates of the graph Range 
+    // min / max dates of the graph Range
     QDate minRangeStartDate;
     QDate maxRangeEndDate;
 
@@ -189,6 +198,12 @@ class Overview : public QWidget
     // Are start and end widgets displaying the same month.
     bool samePage;
 
+    SaveGraphLayoutSettings* saveGraphLayoutSettings=nullptr;
+    QString STR_HIDE_ALL_GRAPHS =QString(tr("Hide All Graphs"));
+    QString STR_SHOW_ALL_GRAPHS =QString(tr("Show All Graphs"));
+    void showGraph(int index,bool show, bool updateGraph);
+    void showAllGraphs(bool show);
+
 };
 
 
