@@ -7,6 +7,9 @@
  * License. See the file COPYING in the main directory of the source code
  * for more details. */
 
+#define TEST_MACROS_ENABLEDoff
+#include <test_macros.h>
+
 #include <QApplication>
 #include <QFile>
 #include <QDataStream>
@@ -23,6 +26,7 @@
 #include "cprogressbar.h"
 #include "SleepLib/common.h"
 #include "version.h"
+#include "SleepLib/profiles.h"
 
 extern MainWindow *mainwin;
 
@@ -48,7 +52,7 @@ QString formatTime(float time)
     int seconds = time * 3600.0;
     int minutes = (seconds / 60) % 60;
     //seconds %= 60;
-    return QString().sprintf("%02i:%02i", hours, minutes); //,seconds);
+    return QString::asprintf("%02i:%02i", hours, minutes); //,seconds);
 }
 
 
@@ -138,7 +142,18 @@ void Statistics::loadRXChanges()
 
     in >> rxitems;
 
+    {   // Bug Fix. during testing, a crash occured due to a null machie value. in saveRxChanges. out << rx.machine->loaderName()
+        QList<QDate> toErase;
+        for (auto ri = rxitems.begin(); ri != rxitems.end();++ri ) {
+            RXItem rxitem = ri.value();
+            if (rxitem.machine==0) toErase.append(ri.key());
+        }
+        for (auto date : toErase) {
+            rxitems.remove(date) ;
+        }
+    }
 }
+
 void Statistics::saveRXChanges()
 {
     QString path = p_profile->Get("{" + STR_GEN_DataFolder + "}/RXChanges.cache" );
@@ -162,6 +177,91 @@ bool rxAHILessThan(const RXItem * rx1, const RXItem * rx2)
     return (double(rx1->ahi) / rx1->hours) < (double(rx2->ahi) / rx2->hours);
 }
 
+void Statistics::updateDisabledInfo()
+{
+    QDate lastcpap = p_profile->LastGoodDay(MT_CPAP);
+    QDate firstcpap = p_profile->FirstGoodDay(MT_CPAP);
+    if (lastcpap > p_profile->general->statReportDate() ) {
+        lastcpap = p_profile->general->statReportDate();
+    }
+    disabledInfo.update( lastcpap, firstcpap );
+}
+
+void DisabledInfo::update(QDate latestDate, QDate earliestDate)
+{
+    clear();
+    if  ( (!latestDate.isValid()) ||  (!earliestDate.isValid()) || (p_profile->cpap->clinicalMode()) ) return;
+    qint64 complianceHours = 3600000.0 * p_profile->cpap->complianceHours();  // conbvert to ms
+    totalDays = 1+earliestDate.daysTo(latestDate);
+    for (QDate date = latestDate ; date >= earliestDate ; date=date.addDays(-1) ) {
+        Day* day = p_profile->GetDay(date);
+        if (!day) { daysNoData++; continue;};
+        // find basic statistics for a day
+        int numDisabled=0;
+        qint64 sessLength = 0;
+        qint64 dayLength = 0;
+        qint64 enabledLength = 0;
+        QList<Session *> sessions = day->getSessions(MT_CPAP,true);
+        for (auto & sess : sessions) {
+            sessLength = sess->length();
+            //if (sessLength<0) sessLength=0; // some sessions have negative length. Sould solve this issue
+            dayLength += sessLength;
+            if (sess->enabled(true)) {
+                enabledLength += sessLength;
+            } else {
+                numDisabled ++;
+                totalDurationOfDisabledSessions += sessLength;
+                if (maxDurationOfaDisabledsession < sessLength) maxDurationOfaDisabledsession = sessLength;
+            }
+        }
+        // calculate stats for all days
+        // calculate if compliance for a day changed.
+        if ( complianceHours <= enabledLength ) {
+            daysInCompliance ++;
+        } else {
+            if (complianceHours < dayLength ) {
+                numDaysDisabledSessionChangedCompliance++;
+            } else {
+                daysOutOfCompliance ++;
+            }
+        }
+        // update disabled info for all days
+        if ( numDisabled > 0 ) {
+            numDisabledsessions += numDisabled;
+            numDaysWithDisabledsessions++;
+        };
+    }
+    // convect ms to minutes
+    maxDurationOfaDisabledsession/=60000 ;
+    totalDurationOfDisabledSessions/=60000 ;
+};
+
+QString DisabledInfo::display(int type)
+{
+/*
+Permissive mode: some sessions are excluded from this report, as follows:
+Total disabled sessions: xx, found in yy days.
+Duration of longest disabled session: aa minutes, Total duration of all disabled sessions: bb minutes.
++tr("Date: %1 AHI: %2").arg(it.value().toString(Qt::SystemLocaleShortDate)).arg(it.key(), 0, 'f', 2) + "</a><br>";
+*/
+    switch (type) {
+        default :
+        case 0:
+            //return QString(QObject::tr("Permissive mode is set (Preferences/Clinical), disabled sessions are excluded from this report"));
+            //return QString(QObject::tr("Permissive mode allows disabled sessions"));
+            return QString(QObject::tr("Permissive Mode"));
+        case 1:
+            if (numDisabledsessions>0) {
+                return QString(QObject::tr("Total disabled sessions: %1, found in %2 days") .arg(numDisabledsessions) .arg(numDaysWithDisabledsessions));
+            } else {
+                return QString(QObject::tr("Total disabled sessions: %1") .arg(numDisabledsessions) );
+            }
+        case 2:
+            return QString(QObject::tr( "Duration of longest disabled session: %1 minutes, Total duration of all disabled sessions: %2 minutes.")
+                .arg(maxDurationOfaDisabledsession, 0, 'f', 1) .arg(totalDurationOfDisabledSessions, 0, 'f', 1));
+    }
+}
+
 void Statistics::updateRXChanges()
 {
     // Set conditional progress bar.
@@ -195,7 +295,7 @@ void Statistics::updateRXChanges()
             continue;
 
         if (day->first() == 0) {  // Ignore invalid dates
-            qDebug() << "Statistics::updateRXChanges ignoring day with first=0";
+            //qDebug() << "Statistics::updateRXChanges ignoring day with first=0";
             continue;
         }
 
@@ -534,6 +634,14 @@ Statistics::Statistics(QObject *parent) :
     QObject(parent)
 {
     rows.push_back(StatisticsRow(tr("CPAP Statistics"), SC_HEADING, MT_CPAP));
+    if (!p_profile->cpap->clinicalMode()) {
+        updateDisabledInfo();
+        rows.push_back(StatisticsRow(disabledInfo.display(0),SC_WARNING ,MT_CPAP));
+        rows.push_back(StatisticsRow(disabledInfo.display(1),SC_WARNING2,MT_CPAP));
+        if (disabledInfo.size()>0) {
+            rows.push_back(StatisticsRow(disabledInfo.display(2),SC_WARNING2,MT_CPAP));
+        }
+    }
     rows.push_back(StatisticsRow("",   SC_DAYS, MT_CPAP));
     rows.push_back(StatisticsRow("", SC_COLUMNHEADERS, MT_CPAP));
     rows.push_back(StatisticsRow(tr("CPAP Usage"),  SC_SUBHEADING, MT_CPAP));
@@ -601,7 +709,7 @@ Statistics::Statistics(QObject *parent) :
     // These are for formatting the headers for the first column
     int percentile=trunc(p_profile->general->prefCalcPercentile());                    // Pholynyk, 10Mar2016
     char perCentStr[20];
-    snprintf(perCentStr, 20, "%d%% %%1", percentile);          // 
+    snprintf(perCentStr, 20, "%d%% %%1", percentile);          //
     calcnames[SC_UNDEFINED] = "";
     calcnames[SC_MEDIAN] = tr("%1 Median");
     calcnames[SC_AVG] = tr("Average %1");
@@ -656,7 +764,6 @@ QString Statistics::getUserInfo () {
 }
 
 const QString table_width = "width='100%'";
-
 // Create the page header in HTML.  Includes everything from <head> through <body>
 QString Statistics::generateHeader(bool onScreen)
 {
@@ -879,11 +986,39 @@ struct Period {
         end=copy.end;
         header=copy.header;
     }
+    Period(QDate first,QDate last,bool& finished, int advance , bool month,QString name) {
+        if (finished) return;
+        // adds date range to header.
+        // replaces the following
+        // periods.push_back(Period(qMax(last.addDays(-6), first), last, tr("Last Week")));
+        QDate next;
+        if (month) {
+            // note add days or addmonths returns the start of the next day or the next month.
+            // must shorten one day for Month.
+            next = last.addMonths(advance).addDays(+1);
+        } else {
+            next = last.addDays(advance);
+        }
+        if (next<=first) {
+            finished = true;
+            next = first;
+        }
+        name = name + "<br>"  + next.toString(Qt::SystemLocaleShortDate) ;
+        if (advance!=0) {
+            name =  name + " - "  +  last.toString(Qt::SystemLocaleShortDate);
+        }
+        this->header = name;
+        this->start = next ;
+        this->end = last ;
+    }
+    Period& operator=(const Period&) = default;
+    ~Period() {};
     QDate start;
     QDate end;
     QString header;
 };
 
+const QString warning_color="#ffffff";
 const QString heading_color="#ffffff";
 const QString subheading_color="#e0e0e0";
 //const int rxthresh = 5;
@@ -934,6 +1069,9 @@ QString Statistics::GenerateMachineList()
 //qDebug() << "Device" << m->brand() << "series" << m->series() << "model" << m->model() << "model number" << m->modelnumber();
             QDate d1 = m->FirstDay();
             QDate d2 = m->LastDay();
+            if (d2 > p_profile->general->statReportDate() ) {
+                d2 = p_profile->general->statReportDate();
+            }
             QString mn = m->modelnumber();
             html += QString("<tr><td>%1</td><td>%2</td><td>%3</td><td>%4</td><td>%5</td></tr>")
                     .arg(m->brand())
@@ -1008,6 +1146,9 @@ QString Statistics::GenerateRXChanges()
     while (it.hasPrevious()) {
         it.previous();
         const RXItem & rx = it.value();
+        if (rx.start > p_profile->general->statReportDate() ) continue;
+        QDate rxend=rx.end;
+        if (rxend > p_profile->general->statReportDate() ) rxend = p_profile->general->statReportDate();
 
         QString color;
 
@@ -1026,7 +1167,7 @@ QString Statistics::GenerateRXChanges()
         html += QString("<tr %4 bgcolor='%1' onmouseover='ChangeColor(this, \"#dddddd\");' onmouseout='ChangeColor(this, \"%1\");' onclick='alert(\"overview=%2,%3\");'>")
                 .arg(color)
                 .arg(rx.start.toString(Qt::ISODate))
-                .arg(rx.end.toString(Qt::ISODate))
+                .arg(rxend.toString(Qt::ISODate))
                 .arg(datarowclass);
 
         double ahi = rdi ? (double(rx.rdi) / rx.hours) : (double(rx.ahi) /rx.hours);
@@ -1040,7 +1181,7 @@ QString Statistics::GenerateRXChanges()
                                                            .arg(rx.machine->serial());
 
         html += QString("<td>%1</td>").arg(rx.start.toString(MedDateFormat))+
-                QString("<td>%1</td>").arg(rx.end.toString(MedDateFormat))+
+                QString("<td>%1</td>").arg(rxend.toString(MedDateFormat))+
                 QString("<td>%1</td>").arg(rx.days)+
                 QString("<td>%1</td>").arg(ahi, 0, 'f', 2)+
                 QString("<td>%1</td>").arg(fli, 0, 'f', 2)+
@@ -1103,19 +1244,9 @@ QString Statistics::GenerateCPAPUsage()
     // Find first and last days with valid CPAP data
     QDate lastcpap = p_profile->LastGoodDay(MT_CPAP);
     QDate firstcpap = p_profile->FirstGoodDay(MT_CPAP);
-
-    // Get dates for standard report (last week, month, 6 months, year)
-    QDate cpapweek = lastcpap.addDays(-6);
-    QDate cpapmonth = lastcpap.addDays(-29);
-    QDate cpap6month = lastcpap.addMonths(-6);
-    QDate cpapyear = lastcpap.addMonths(-12);
-
-    // but not before the first available date of course
-    if (cpapweek   < firstcpap) { cpapweek   = firstcpap; }
-    if (cpapmonth  < firstcpap) { cpapmonth  = firstcpap; }
-    if (cpap6month < firstcpap) { cpap6month = firstcpap; }
-    if (cpapyear   < firstcpap) { cpapyear   = firstcpap; }
-
+    if (lastcpap > p_profile->general->statReportDate() ) {
+        lastcpap = p_profile->general->statReportDate();
+    }
 
     QString ahitxt = getRDIorAHIText();
 
@@ -1157,15 +1288,21 @@ QString Statistics::GenerateCPAPUsage()
         if (row.calc == SC_HEADING) {  // All sections begin with a heading
             last = p_profile->LastGoodDay(row.type);
             first = p_profile->FirstGoodDay(row.type);
+            if (last > p_profile->general->statReportDate() ) {
+                last = p_profile->general->statReportDate();
+            }
 
             // Clear the periods (columns)
             periods.clear();
             if (p_profile->general->statReportMode() == STAT_MODE_STANDARD) {
-                periods.push_back(Period(last,last,tr("Most Recent")));
-                periods.push_back(Period(qMax(last.addDays(-6), first), last, tr("Last Week")));
-                periods.push_back(Period(qMax(last.addDays(-29),first), last, tr("Last 30 Days")));
-                periods.push_back(Period(qMax(last.addMonths(-6), first), last, tr("Last 6 Months")));
-                periods.push_back(Period(qMax(last.addMonths(-12), first), last, tr("Last Year")));
+                // note add days or addmonths returns the start of the next day or the next month.
+                // must shorten one day for each. Month executed in Period method
+                bool finished = false;  // used to detect end of data - when less than a year of data.
+                periods.push_back(Period(first,last,finished, 0, false ,tr("Most Recent")));
+                periods.push_back(Period(first,last,finished, -6, false ,tr("Last Week")));
+                periods.push_back(Period(first,last,finished, -29,false, tr("Last 30 Days")));
+                periods.push_back(Period(first,last,finished, -6,true, tr("Last 6 Months")));
+                periods.push_back(Period(first,last,finished, -12,true,tr("Last Year")));
             } else if (p_profile->general->statReportMode() == STAT_MODE_MONTHLY) {
                 QDate l=last,s=last;
 
@@ -1180,10 +1317,10 @@ QString Statistics::GenerateCPAPUsage()
                         s = first;
                     }
                     if (p_profile->countDays(row.type, s, l) > 0) {
-                        periods.push_back(Period(s, l, s.toString("MMMM")));
+                        periods.push_back(Period(s, l, s.toString("MMMM<br>yyyy")));
                         j++;
                     }
-                    l = s.addDays(-1);
+                   l = s.addDays(-1);
                 } while ((l > first) && (j < number_periods));
 
                 for (; j < number_periods; ++j) {
@@ -1192,7 +1329,10 @@ QString Statistics::GenerateCPAPUsage()
             } else {            // STAT_MODE_RANGE
                 first = p_profile->general->statReportRangeStart();
                 last = p_profile->general->statReportRangeEnd();
-                periods.push_back(Period(first,last,first.toString(MedDateFormat)+" -<br/>"+last.toString(MedDateFormat)));
+                if (first > last) {
+                    first = last;
+                }
+                periods.push_back(Period(first,last,first.toString(MedDateFormat)+" - "+last.toString(MedDateFormat)));
             }
 
             int days = p_profile->countDays(row.type, first, last);
@@ -1223,21 +1363,24 @@ QString Statistics::GenerateCPAPUsage()
         } else if (row.calc == SC_DAYS) {
             QDate first=p_profile->FirstGoodDay(row.type);
             QDate last=p_profile->LastGoodDay(row.type);
+            if (last > p_profile->general->statReportDate() ) {
+                last = p_profile->general->statReportDate();
+            }
             QString & machine = machinenames[row.type];
             int value=p_profile->countDays(row.type, first, last);
 
             if (value == 0) {
                 html+=QString("<tr><td colspan=%1 align=center>%2</td></tr>").arg(periods.size()+1).
-                        arg(tr("No %1 data available.").arg(machine));
+                        arg(tr("Database has No %1 data available.").arg(machine));
             } else if (value == 1) {
                 html+=QString("<tr><td colspan=%1 align=center>%2</td></tr>").arg(periods.size()+1).
-                        arg(tr("%1 day of %2 Data on %3")
+                        arg(tr("Database has %1 day of %2 Data on %3")
                             .arg(value)
                             .arg(machine)
                             .arg(last.toString(MedDateFormat)));
             } else {
                 html+=QString("<tr><td colspan=%1 align=center>%2</td></tr>").arg(periods.size()+1).
-                        arg(tr("%1 days of %2 Data, between %3 and %4")
+                        arg(tr("Database has %1 days of %2 Data, between %3 and %4")
                             .arg(value)
                             .arg(machine)
                             .arg(first.toString(MedDateFormat))
@@ -1250,6 +1393,16 @@ QString Statistics::GenerateCPAPUsage()
             continue;
         } else if (row.calc == SC_UNDEFINED) {
             continue;
+        } else if (row.calc == SC_WARNING) {
+                //html+=QString("<tr bgcolor='%1'><td colspan=%2 align=center><font size='+1'>%3</font></td></tr>").
+                //        arg(warning_color).arg(periods.size()+1).arg(row.src);
+                html+=QString("<tr bgcolor='%1'><th colspan=%2 align=center><font size='+0'><i>%3</i></font></th></tr>").
+                        arg(warning_color).arg(periods.size()+1).arg(row.src);
+            continue;
+        } else if (row.calc == SC_WARNING2) {
+                html+=QString("<tr bgcolor='%1'><th colspan=%2 align=center><font size='+0'><i>%3</i></font></th></tr>").
+                        arg(warning_color).arg(periods.size()+1).arg(row.src);
+            continue;
         } else {
             ChannelID id = schema::channel[row.src].id();
             if ((id == NoChannel) || (!p_profile->channelAvailable(id))) {
@@ -1257,12 +1410,15 @@ QString Statistics::GenerateCPAPUsage()
             }
             name = calcnames[row.calc].arg(schema::channel[id].fullname());
         }
+        // Defined percentages for columns for diffent modes.
         QString line;
         int np = periods.size();
         int width;
+        // both create header column and 5 data columns for a total of 100
         int dataWidth = 14;
         int headerWidth = 30;
         if (p_profile->general->statReportMode() == STAT_MODE_MONTHLY) {
+            // both create header column and 13  data columns for a total of 100
             dataWidth = 6;
             headerWidth = 22;
         }
@@ -1325,12 +1481,13 @@ void Statistics::printReport(QWidget * parent) {
 #endif
 
     printer.setPrintRange(QPrinter::AllPages);
-    printer.setOrientation(QPrinter::Portrait);
+    printer.setPageOrientation(QPageLayout::Portrait);
     printer.setFullPage(false);     // Print only on printable area of page and not in non-printable margins
-    printer.setNumCopies(1);
+    printer.setCopyCount(1);
 
     QMarginsF minMargins = printer.pageLayout().margins(QPageLayout::Millimeter);
-    printer.setPageMargins(fmax(10,minMargins.left()), fmax(10,minMargins.top()), fmax(10,minMargins.right()), fmax(12,minMargins.bottom()), QPrinter::Millimeter);
+
+    printer.setPageMargins( QMarginsF( fmax(10,minMargins.left()), fmax(10,minMargins.top()), fmax(10,minMargins.right()), fmax(12,minMargins.bottom())), QPageLayout::Millimeter);
     QMarginsF setMargins = printer.pageLayout().margins(QPageLayout::Millimeter);
     qDebug () << "Min margins" << minMargins << "Set margins" << setMargins << "millimeters";
 
@@ -1389,20 +1546,27 @@ QString Statistics::UpdateRecordsBox()
         /////////////////////////////////////////////////////////////////////////////////////
         /// Compliance and usage information
         /////////////////////////////////////////////////////////////////////////////////////
-        int totaldays = p_profile->countDays(MT_CPAP, first, last);
+        int totalDays = 1+first.daysTo(last);
+        int daysUsed = p_profile->countDays(MT_CPAP, first, last);
+        int daysSkipped = totalDays - daysUsed;
         int compliant = p_profile->countCompliantDays(MT_CPAP, first, last);
-
-        float comperc = (100.0 / float(totaldays)) * float(compliant);
+        int lowUsed = daysUsed - compliant;
+        float comperc = (100.0 / float(totalDays)) * float(compliant);
 
         html += "<b>"+tr("CPAP Usage")+"</b><br>";
-        html += tr("Days Used: %1").arg(totaldays) + "<br>";
-        html += tr("Low Use Days: %1").arg(totaldays - compliant) + "<br>";
+        html += first.toString(Qt::SystemLocaleShortDate) + " - " +  last.toString(Qt::SystemLocaleShortDate) + "<br>";
+        if (daysSkipped > 0) {
+            html += tr("Total Days: %1").arg(totalDays) + "<br>";
+            html += tr("Days Not Used: %1").arg(daysSkipped) + "<br>";
+        }
+        html += tr("Days Used: %1").arg(daysUsed) + "<br>";
+        html += tr("Days %1 %2 Hours: %3").arg("&gt;=")  .arg(p_profile->cpap->complianceHours(),0,'f',1) .arg(compliant) + "<br>";
+        html += tr("Days %1 %2 Hours: %3").arg("&lt;").arg(p_profile->cpap->complianceHours(),0,'f',1) .arg(lowUsed) + "<br>";
         html += tr("Compliance: %1%").arg(comperc, 0, 'f', 1)  + "<br>";
 
         /////////////////////////////////////////////////////////////////////////////////////
         /// AHI Records
         /////////////////////////////////////////////////////////////////////////////////////
-
         if (p_profile->session->preloadSummaries()) {
             const int show_records = 5;
             QMultiMap<float, QDate>::iterator it;
@@ -1412,7 +1576,7 @@ QString Statistics::UpdateRecordsBox()
             int baddays = 0;
 
             for (QDate date = first; date <= last; date = date.addDays(1)) {
-                Day * day = p_profile->GetGoodDay(date, MT_CPAP);
+                Day * day = p_profile->GetDay(date, MT_CPAP);
                 if (!day) continue;
 
                 float ahi = day->calcAHI();
@@ -1457,7 +1621,7 @@ QString Statistics::UpdateRecordsBox()
 
             ahilist.clear();
             for (QDate date = first; date <= last; date = date.addDays(1)) {
-                Day * day = p_profile->GetGoodDay(date, MT_CPAP);
+                Day * day = p_profile->GetDay(date, MT_CPAP);
                 if (!day) continue;
 
                 float val = 0;
@@ -1509,7 +1673,7 @@ QString Statistics::UpdateRecordsBox()
 
             ahilist.clear();
             for (QDate date = first; date <= last; date = date.addDays(1)) {
-                Day * day = p_profile->GetGoodDay(date, MT_CPAP);
+                Day * day = p_profile->GetDay(date, MT_CPAP);
                 if (!day) continue;
 
                 float leak = day->calcPON(CPAP_LargeLeak);
@@ -1547,7 +1711,7 @@ QString Statistics::UpdateRecordsBox()
             if (p_profile->hasChannel(CPAP_CSR)) {
                 ahilist.clear();
                 for (QDate date = first; date <= last; date = date.addDays(1)) {
-                    Day * day = p_profile->GetGoodDay(date, MT_CPAP);
+                    Day * day = p_profile->GetDay(date, MT_CPAP);
                     if (!day) continue;
 
                     float leak = day->calcPON(CPAP_CSR);
@@ -1577,7 +1741,7 @@ QString Statistics::UpdateRecordsBox()
             if (p_profile->hasChannel(CPAP_PB)) {
                 ahilist.clear();
                 for (QDate date = first; date <= last; date = date.addDays(1)) {
-                    Day * day = p_profile->GetGoodDay(date, MT_CPAP);
+                    Day * day = p_profile->GetDay(date, MT_CPAP);
                     if (!day) continue;
 
                     float leak = day->calcPON(CPAP_PB);
@@ -1628,7 +1792,7 @@ QString Statistics::UpdateRecordsBox()
 
 
         if (list.size() >= 2) {
-            html += "<b>"+tr("Best RX Setting")+"</b><br>";
+            html += "<b>"+tr("Best Device Setting")+"</b><br>";
             const RXItem & rxbest = *list.at(0);
             html += QString("<a href='overview=%1,%2'>").arg(rxbest.start.toString(Qt::ISODate)).arg(rxbest.end.toString(Qt::ISODate)) +
                 tr("Date: %1 - %2").arg(rxbest.start.toString(Qt::SystemLocaleShortDate)).arg(rxbest.end.toString(Qt::SystemLocaleShortDate)) + "</a><br>";
@@ -1640,7 +1804,7 @@ QString Statistics::UpdateRecordsBox()
             html += QString("%1").arg(formatRelief(rxbest.relief)) + "<br>";
             html += "<br>";
 
-            html += "<b>"+tr("Worst RX Setting")+"</b><br>";
+            html += "<b>"+tr("Worst Device Setting")+"</b><br>";
             const RXItem & rxworst = *list.at(list.size() -1);
             html += QString("<a href='overview=%1,%2'>").arg(rxworst.start.toString(Qt::ISODate)).arg(rxworst.end.toString(Qt::ISODate)) +
                     tr("Date: %1 - %2").arg(rxworst.start.toString(Qt::SystemLocaleShortDate)).arg(rxworst.end.toString(Qt::SystemLocaleShortDate)) + "</a><br>";
@@ -1741,3 +1905,18 @@ QString StatisticsRow::value(QDate start, QDate end)
 
     return value;
 }
+
+QDate lastdate;
+QDate firstdate;
+void Statistics::updateReportDate() {
+    if (p_profile) {
+        QDate last = p_profile->LastDay();
+        QDate first = p_profile->FirstDay();
+        if (last == lastdate  && first == firstdate) return;
+        p_profile->general->setStatReportRangeStart(first);
+        p_profile->general->setStatReportRangeEnd(last);
+        p_profile->general->setStatReportDate(last);
+        lastdate = last;
+        firstdate = first;
+    }
+}
